.. _all-salt.states:

==================================
Full list of builtin state modules
==================================

.. currentmodule:: salt.states

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    alias
    alternatives
    apache
    apache_module
    apt
    archive
    at
    augeas
    aws_sqs
    blockdev
    boto_asg
    boto_cloudwatch_alarm
    boto_elasticache
    boto_elb
    boto_iam_role
    boto_lc
    boto_route53
    boto_secgroup
    boto_sqs
    cloud
    cmd
    composer
    cron
    ddns
    debconfmod
    disk
    dockerio
    environ
    eselect
    event
    file
    gem
    git
    glusterfs
    gnomedesktop
    grains
    group
    hg
    host
    htpasswd
    incron
    influxdb_database
    influxdb_user
    ini_manage
    ipset
    iptables
    keyboard
    keystone
    kmod
    layman
    libvirt
    locale
    lvm
    lvs_server
    lvs_service
    lxc
    makeconf
    mdadm
    memcached
    modjk
    modjk_worker
    module
    mongodb_database
    mongodb_user
    mount
    mysql_database
    mysql_grants
    mysql_query
    mysql_user
    network
    nftables
    npm
    ntp
    openstack_config
    pagerduty
    pecl
    pip_state
    pkg
    pkgng
    pkgrepo
    portage_config
    ports
    postgres_database
    postgres_extension
    postgres_group
    postgres_user
    powerpath
    process
    pyenv
    quota
    rabbitmq_cluster
    rabbitmq_plugin
    rabbitmq_policy
    rabbitmq_user
    rabbitmq_vhost
    rbenv
    rdp
    redismod
    reg
    rvm
    saltmod
    schedule
    selinux
    serverdensity_device
    service
    smtp
    ssh_auth
    ssh_known_hosts
    stateconf
    status
    supervisord
    svn
    sysctl
    test
    timezone
    tomcat
    user
    virtualenv_mod
    win_dns_client
    win_firewall
    win_network
    win_path
    win_servermanager
    win_system
    win_update
    winrepo
    xmpp
    zcbuildout
    zk_concurrency
